Structs
- Binned
Metrics Extractor - Parquet
Helper - Now that we have at least 2 metric types that calculate avg, lower_bound, and upper_bound as part of their stats, it makes sense to implement a generic trait that we can use.
Functions
- create_
attr_ match_ udf - Create the
match_attrScalarUDFusing the DataFusion 52ScalarUDFImplAPI. - match_
attr_ expr - Build a DataFusion
Exprthat callsmatch_attr(search_blob, pattern).