Module utils

Module utils 

Structs

BinnedMetricsExtractor
ParquetHelper
Now that we have at least 2 metric types that calculate avg, lower_bound, and upper_bound as part of their stats, it makes sense to implement a generic trait that we can use.

Functions

create_attr_match_udf
Create the match_attr ScalarUDF using the DataFusion 52 ScalarUDFImpl API.
match_attr_expr
Build a DataFusion Expr that calls match_attr(search_blob, pattern).